@@ -1,6 +1,6 @@
 # barcode_dialog.py
 #
-# Copyright 2022 Pablo Sánchez Rodríguez
+# Copyright 2022-2024 Pablo Sánchez Rodríguez
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@ from gi.repository import Adw, Gtk
 
 
 @Gtk.Template(resource_path='/me/sanchezrodriguez/passes/barcode_dialog.ui')
-class BarcodeDialog(Adw.Window):
+class BarcodeDialog(Adw.Dialog):
 
     __gtype_name__ = 'BarcodeDialog'
 
